<?php
/**
 * Webkul Software.
 *
 * @category  Webkul
 * @package   Webkul_Eshopsync
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Observer;
 
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\RequestInterface;

class OnContactusPost implements ObserverInterface
{
    /** @var \Magento\Framework\Logger\Monolog */
    protected $_logger;

    /** @var \Webkul\SalesforceConnector\Helper\Connection */
    protected $_helperConnection;
    protected $_helperData;

    /** @var Magento\Framework\App\RequestInterface */
    protected $_request;

    /** @var \Webkul\SalesforceConnector\Helper\Contactus */
    protected $_helperContactus;

    /**
     * @param \Psr\Log\LoggerInterface            $loggerInterface
     * @param \Webkul\SalesforceConnector\Helper\Connection $helperConnection
     * @param RequestInterface                    $requestInterface
     * @param \Webkul\SalesforceConnector\Helper\Contactus    $helperContactus
     */
    public function __construct(
        \Psr\Log\LoggerInterface $loggerInterface,
        \Webkul\SalesforceConnector\Helper\Connection $helperConnection,
        \Webkul\SalesforceConnector\Helper\Data $helperData,
        RequestInterface $requestInterface,
        \Webkul\SalesforceConnector\Helper\Contactus $helperContactus
    ) {
    
        $this->_logger = $loggerInterface;
        $this->_helperConnection = $helperConnection;
        $this->_helperData = $helperData;
        $this->_request = $requestInterface;
        $this->_helperContactus = $helperContactus;
    }
    /**
     * This is the method that fires when the event runs.
     *
     * @param Observer $observer
     */

    public function execute(Observer $observer)
    {
        $data = $observer->getData();
        
        $post = $data['controller_action']->getRequest()->getPost();
        $autoSync = $this->_helperData->getConfigValue('autoSync', 'autoSyncContactSync');
        if ($post && $autoSync) {
            //$client = $this->_helperConnection->getSforceConnection();
            //if ($client['client']) {
                $sObject = new \stdClass();
                $sObject->LastName = $post['name'];
                $sObject->Company = $post['name'];
                $sObject->Phone = $post['telephone'];
                $sObject->LeadSource = 'Web';
                $sObject->Email = $post['email'];
                $sObject->Description = $post['comment'];
            try {
                $leadResponse = $this->_helperConnection->insertSObject('Lead', $sObject);
                    
                // foreach ($leadResponse as $record) {
                //     $leadId = $record->id;
                if ($leadResponse) {
                    $post['sforce_id'] = $leadResponse;
                    // $post['created_by'] = $leadResponse;
                    $this->_helperContactus->contactusMapping($post);
                }
                    // }
            } catch (\Exception $e) {
                $this->_helperData->eshopsyncLog($e->getMessage());
                return false;
            }
            // }
            return true;
        }
    }
}
